/* $Workfile: Dm64Ioctl.h $   $Revision: 4 $    $Modtime: 11/27/07 12:55p $  */
#ifndef DM64_IOCTL_H
#define DM64_IOCTL_H
/*------------------------------------------------------- File Description -*\

  @doc PublicDsp64SdkApi

  Odin TeleSystems Inc.

  SAA-1014-1 OTX DSP C64x Software Development Kit (SDK)

  @module

    Dm64Ioctl.h | Macros and structs for sharing data between a DM644x device and the host.

  @contents2
  Dm64Ioctl.h |

  @index enum struct type | Dm64Ioctl

  @contents2
  Host-Dsp Communication addresses (Dm64Ioctl.h) |

  Overriding some of the macros defined in DspIoctl.h
  
\*--------------------------------------------------------------------------*/


#ifdef HDR_DBG // Define to trace include order of headers
#pragma message("\n" __FILE__ "(1): Including\n")
#endif


#include "DspIoctl.h"

#if defined(__linux__) 
#pragma pack(2)
#elif defined(_TMS320DM64X)
// No pack pragma needed for the DSP compiler
#elif defined(__BORLANDC__)
#pragma option push -a2
#else
#pragma pack(push,2)
#endif

//
// Note the the DM644x TI DaVinci has two processors and ARM and a DSP. 
// Defines with DMP are for ARM and defines with DSP are for the DSP
//


// @type OTXDSP_SDK_MAX_TIMESLOTS_PER_HIGHWAY | Otx DSP SDK Number of 64kbit/s timeslots per highway (on a 8Mbps highway)
#define OTXDSP_SDK_MAX_TIMESLOTS_PER_HIGHWAY   128
// @type OTXDSP_SDK_MAX_WORDSLOTS_PER_HIGHWAY | Otx DSP SDK Number of 128kbit/s timeslots per highway  (on a 8Mbps highway)
#define OTXDSP_SDK_MAX_WORDSLOTS_PER_HIGHWAY  (OTXDSP_SDK_TIMESLOTS_PER_HIGHWAY/2)

#define OTXDM64_DATA_MAX_SIZE 1500

/*******************************************************************************
  @devnote
   This is the OTP (OTX Transfer Protocol) Header in the UDP packets.
   It is used for both directions (DMP->HOST and HOST->DMP).

   We refer to 'Control' as the HOST->DMP direction.
   We refer to 'Notify'  as the DMP->HOST direction.

*******************************************************************************/
typedef struct {
  OTX_UINT16     nMagicNumber;   // Just for a sanity check of the OTP packet
  OTX_UINT16     nPayloadSize;   // Number of bytes of the payload + this header
  OTX_UINT16     nSeqNo;         // Sequence number of the frame
  OTX_UINT16     nMsgType;       // E.g Command or Response
  OTX_UINT32     nIoCode;        // Device IO Control and Notify Code
  OTX_UINT32     hDevHandle;     // Handle of logical or physical device
  OTX_UINT32     nTaskRef;       // User specified Task Ref field.
  OTX_UINT16     nDataLen;       // Data size (in bytes) contained in pData
  // Data follows directly after the header
} OtxDm64OtpHeaderS;


#define  OTXDM64_MAGIC_NUMBER (0x644 | 0x01)  // The least significant nibble is the version

/*******************************************************************************
  @devnote
   DMP MsgType Bit fields (in OtxDm64IoControlS)
*******************************************************************************/
#define  OTXDM64_MSGTYPE_COMMAND             0x0001 // Bit0; if set, it is a command. If clear it is a response
#define  OTXDM64_MSGTYPE_DATA_COMPLETE       0x0002 // Bit1; if set, the data is complete. If clear, more data will be sent in another packet
#define  OTXDM64_MSGTYPE_DATA_PADDED         0x0004 // Bit2; if set, the data is padded with one byte. If clear, data is not padded


/*******************************************************************************
  @devnote
   DMP Control codes. 
   Note. Control codes below 0x10000 are reserved for DSP54 and DSP55 control codes.
*******************************************************************************/
#if 0 // Just a template
#define OTXDM64_CONTROL_XXX_XXX_XXX          0x00010000   // Sent when ..... Data is OtxDm64ControlXxxXxxXxxS.
#endif

/*******************************************************************************
  @devnote
   DMP Notify Event codes. 
   Note. Event codes below 0x10000 are reserved for DSP54 and DSP55 event codes.
*******************************************************************************/
#define OTXDM64_NOTIFY_DMP_SYSTEM_DATA       0x00010000   // Sent by the DMP->Host upon boot-up. Data is OtxDm64NotifyDmpSystemDataS.


/*******************************************************************************
  @devnote
   Structs for passing data from the DMP to the Host over the IOCTL interface
*******************************************************************************/

// For OTXDM64_NOTIFY_DMP_SYSTEM_DATA
typedef struct 
{
  // DMP Ethernet MAC address and IP address is picked up from the Ethernet and IP headers

  OTX_UINT8    szSerialNo[32];    // Serial number of the DMP

  OTX_UINT8    sqDmpMacAddr[6];   // MAC address of the DMP. Example 00:50:C2:81:70:0B. sqDmpMacAddr[5] is the 0x00 byte (MSB) and sqDmpMacAddr[0] is the 0x0B byte (LSB)
  OTX_UINT16   nPad;              // Just padding
  OTX_UINT8    sqDmpIpAddr[4];    // IP address of the DMP. Example 10.0.1.103. sqDmpIpAddr[3] is the 10 byte (MSB) and sqDmpIpAddr[0] is the 103 byte (LSB)
  OTX_UINT8    sqHostIpAddr[4];   // IP address of the host. Example 10.0.1.200. sqDmpIpAddr[3] is the 10 byte (MSB) and sqDmpIpAddr[0] is the 200 byte (LSB)

  // This is the version of the OtxDavinci.ko that the DMP is running
  OTX_UINT32   nDrvRevNoMajor;    // @field Driver Revision; Major
  OTX_UINT32   nDrvRevNoMinor;    // @field Driver Revision; Minor
  OTX_UINT32   nDrvRevNoPr;       // @field Driver Revision; PR (PR = 0 = Preliminary, PR = 1 = Release, If PR = 1 P-Version is always 0)
  OTX_UINT32   nDrvRevNoPversion; // @field Driver Revision; P-Version: (Only valid if PR = 0)

  OTX_UINT32   nReserved0;        // Reserved for future use
  OTX_UINT32   nReserved1;        // Reserved for future use
  OTX_UINT32   nReserved2;        // Reserved for future use
  OTX_UINT32   nReserved3;        // Reserved for future use

} OtxDm64NotifyDmpSystemDataS;


/*******************************************************************************
  @devnote
   Structs for passing data from the Host to the DMP over the IOCTL interface
*******************************************************************************/
#if 0 // Just a template
// For OTXDM64_CONTROL_XXX_XXX_XXX
typedef struct 
{

  OTX_UINT32   nReserved0;        // Reserved for future use
  OTX_UINT32   nReserved1;        // Reserved for future use
  OTX_UINT32   nReserved2;        // Reserved for future use
  OTX_UINT32   nReserved3;        // Reserved for future use

} OtxDm64ControlXxxXxxXxxS;
#endif




#if defined(__linux__) 
#pragma pack(2)
#elif defined(_TMS320DM64X)
// No pack pragma needed for the DSP compiler
#elif defined(__BORLANDC__)
#pragma option pop
#else
#pragma pack(pop)
#endif


/******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 2007


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

******************************************************************************/
#endif /* DM64_IOCTL_H */
